<template>
    <div class="dialog-table-container sub-page-inner">
        <div class="sub-table-container">
            <el-row :gutter="20" style="margin-bottom: 10px">
                <el-col :span="12" v-if="this.$route.query.code">
                    <span class="search-label">项目名称：</span>
                    <el-input @change="(val) => search(val)" size="small" v-model="searchData['p.pilot_Project_Name_']"
                        clearable suffix-icon="el-icon-search" placeholder="请输入项目名称"
                        style="width: 100%"></el-input></el-col>
                <el-col :span="12">
                    <span class="search-label">制度名称：</span>
                    <el-input @change="(val) => search(val)" size="small" v-model="searchData['r.RESULT_NAME_']" clearable
                        suffix-icon="el-icon-search" placeholder="请输入制度名称" style="width: 100%"></el-input></el-col>
                <el-col :span="12" v-if="!this.$route.query.code">
                    <span class="search-label">搭建区县：</span>
                    <el-input @change="(val) => search(val)" size="small" v-model="searchData['a.UNIT_NAME_']" clearable
                        suffix-icon="el-icon-search" placeholder="请输入搭建区县" style="width: 100%"></el-input></el-col>
            </el-row>
            <el-table ref="dataTable" :element-loading-background="loadingColor" v-loading="loading"
                height="calc(100% - 120px)" highlight-current-row current-row-key="id" align="center" :data="tableData"
                class="dialog_table" :cell-style="{ 'text-align': 'center' }"
                :header-cell-style="{ 'text-align': 'center' }" @expand-change="expandChange"
                @current-change="currentChange" row-key="id">
                <el-table-column prop="resultName" label="制度名称">
                </el-table-column>
                <el-table-column prop="unitName" label="出台区县" width="140">
                </el-table-column>
                <el-table-column prop="resultDate" label="出台日期" width="140"></el-table-column>
            </el-table>
            <pagenation :pageResult="params.pageBean" @currentChange="pageChange" class="pagenation"></pagenation>
        </div>
        <div class="sub-page-detail">
            <div class="bg-de">
                <div class="de-con">
                    <div>
                        <img v-for="(item, index) in 2" :key="index" src="@/assets/img/bigScreen/img_wk_zs2@2x.png" />
                    </div>
                    <div class="title">{{ currentRow.resultName }}</div>
                    <div>
                        <img v-for="(item, index) in 2" :key="index" src="@/assets/img/bigScreen/img_wk_zs2@2x.png" />
                    </div>
                </div>
            </div>
            <el-form label-position="top" class="sub-page--expand" :element-loading-background="loadingColor"
                v-loading="loading">
                <el-row>
                    <el-form-item label="试点项目：">
                        <span> {{ currentRow.pilotProjectName }}</span>
                    </el-form-item>
                </el-row>
                <el-row :gutter="10">
                    <el-col :span="8">
                        <el-form-item label="试点层级：">
                            <span>{{
                                getDictName('sdcj', currentRow.pilotLevel)
                            }}</span>
                        </el-form-item>
                    </el-col>
                    <el-col :span="8">
                        <el-form-item label="出台区县：">
                            <span> {{ currentRow.unitName }}</span>
                        </el-form-item>
                    </el-col>
                    <el-col :span="8">
                        <el-form-item label="出台日期：">
                            <span> {{ currentRow.resultDate }}</span>
                        </el-form-item>
                    </el-col>
                </el-row>
                <el-row>
                    <el-form-item label="解决问题：">
                        <span>{{ currentRow.solveProblem }}</span>
                    </el-form-item>
                </el-row>
                <el-row>
                    <el-form-item label="运行实效：">
                        <span>{{ currentRow.actualEffect }}</span>
                    </el-form-item>
                </el-row>
                <el-row>
                    <el-form-item label="佐证材料：">
                        <el-row v-if="currentRow.fileList">
                            <el-col :span="8" v-for="(file, index) in currentRow.fileList" :key="index">
                                <div class="file-style">
                                    <div class="file-item">
                                        <span class="file-name" :title="file.name
                                            ? file.name
                                            : file.fileName +
                                            '.' +
                                            file.extensionName
                                            ">{{
        file.name
        ? file.name
        : file.fileName +
        '.' +
        file.extensionName
    }}</span>
                                        <span class="file-btn short">
                                            <el-link type="primary" :underline="false" @click="handlePreview(file)"
                                                style="color: #fff">预览</el-link>
                                            <el-link type="primary" :underline="false" style="color: #fff" @click="
                                                handleDownloadFile(file)
                                                ">下载</el-link>
                                        </span>
                                    </div>
                                </div>
                            </el-col>
                        </el-row>
                    </el-form-item>
                </el-row>
            </el-form>
        </div>
        <filePreview ref="filePreview" :appendToBody="true"></filePreview>
    </div>
</template>
<script>
import filePreview from '@/components/FilePreview/filePreview.vue'
import apiList from '@/api/bigScreen/districView.js'
import utils from '@/utils.js'
const portal = window.context.portal
import pagenation from './pagenation.vue'
export default {
    components: { pagenation, filePreview },
    props: {
        options: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            previewUrl: `${portal}/file/onlinePreviewController/v1/getFileById_`,
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            loading: false,
            tableData: [],
            currentRow: {},
            searchData: {},
            params: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0,
                    showTotal: true,
                },
                params: {},
                querys: [
                    
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'r.RESULT_FORM_',
                        relation: 'AND',
                        value: 1,
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'a.unit_code_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'PILOT_LEVEL_',
                        relation: 'AND',
                        value: '1',
                    },
                ],
            },
            paramsFile: {
                pageBean: {
                    page: 1,
                    pageSize: -1,
                    showTotal: true,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'BIZ_ID_',
                        relation: 'AND',
                        value: '',
                    },
                ],
            },
        }
    },
    mounted() {
        if (this.$route.query.projectName) {
            this.searchData['p.pilot_Project_Name_'] =
                this.$route.query.projectName
            this.search()
        } else {
            this.loadData()
        }

        this.$bus.$on('changeDate', () => {
            this.loadData()
        })
    },
    beforeDestroy() {
        this.tableData = []
        this.currentRow = {}
    },
    methods: {
        search(data, type) {
            this.params.pageBean.page = 1
            let RESULT_FORM_ = this.params.querys[0]
            let UNIT_CODE_ = this.params.querys[1]
            let PILOT_LEVEL_ = this.params.querys[2]
            this.params.querys = [RESULT_FORM_, UNIT_CODE_,PILOT_LEVEL_]
            for (let key in this.searchData) {
                this.params.querys.push({
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: key,
                    relation: 'AND',
                    value: this.searchData[key],
                })
            }
            this.loadData()
        },
        currentChange(currentRow, oldCurrentRow) {
            // console.log(currentRow, oldCurrentRow)
            this.getFiles(currentRow)
            this.currentRow = currentRow
        },
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        pageChange(key) {
            this.params.pageBean.page = key
            this.loadData()
        },
        expandChange(row, expandedRows) {
            console.log(row, expandedRows)
            if (row.fileList) return
            this.getFiles(row)
        },
        getFiles(row) {
            this.paramsFile.querys[0].value = row.id
            apiList.getFiles(this.paramsFile, (data) => {
                this.currentRow.fileList = data.rows
            })
        },
        handlePreview(file) {
            let id = file.fileId
                ? file.fileId
                : file.id
                    ? file.id
                    : file.response.fileId
            let type = file.fileType || (file.extensionName
                ? file.extensionName
                : file.name.split('.')[1])
            this.$refs.filePreview.previewUrl = this.previewUrl + id
            this.$refs.filePreview.open(type)
        },
        // 文件下载
        handleDownloadFile(file) {
            console.log(file)
            let id = file.fileId
                ? file.fileId
                : file.id
                    ? file.id
                    : file.response.fileId
            window.open(portal + `/file/v1/downloadFile?fileId=${id}`, '_self')
        },
        loadData() {
            this.loading = true
            let { code, projectName } = this.$route.query
            let searchDate = sessionStorage.getItem('searchDate')
            searchDate = JSON.parse(searchDate)
            this.params.params = {
                year: searchDate.year,
                quarter: searchDate.quarter,
            }
            this.params.querys[1].value = code

            apiList.getPilotResultDetail(this.params, (res) => {
                if (res && res.rows) {
                    this.tableData = res.rows
                    this.params.pageBean.page = res.page
                    this.params.pageBean.pageSize = res.pageSize
                    this.params.pageBean.total = res.total
                    if (this.tableData.length) {
                        this.currentRow = this.tableData[0]
                        this.$nextTick(() => {
                            this.$refs.dataTable.setCurrentRow(
                                this.$refs.dataTable.data[0]
                            )
                            this.getFiles(this.currentRow)
                        })
                    } else {
                        this.currentRow = {}
                    }
                }
                this.loading = false
            })
        },
    },
}
</script>
<style lang="scss" scoped></style>
<style lang="scss">
@import './table.scss';
</style>
